# Bulker

[![PEP compatible](https://pepkit.github.io/img/PEP-compatible-green.svg)](http://pepkit.github.io) [![Build Status](https://travis-ci.org/databio/bulker.svg?branch=master)](https://travis-ci.org/databio/bulker)

Bulker builds multi-container computing environments that are both **modular** and **interactive**. 

For details, see the [bulker documentation](http://docs.bulker.io). You can find and share manifests at [bulker hub](http://hub.bulker.io).
